Status
======

.. toctree::
   :hidden:

   get_ping
   get_status


Introduction
------------

This API provides real-time status report for availability and performance status of the platform services.


Resources
---------

- :doc:`get_ping`: provide a simple mechanism to help developers or other remote services ensure that their software is interacting correctly with the web services infrastructure, to measure the round-trip time for requests sent from the local host to the Web services server.

- :doc:`get_status`: provide the status of different software components that the platform is built on.
